@@ -41,9 +41,12 @@ foreach my $hostname qw(main dev1 dev2) {
 #===================================
 sub get_path {
 #===================================
-    return
-        File::Spec->catdir( (
-            File::Spec->splitpath( File::Spec->rel2abs($0)))[ 0, 1 ],@_
-        );
+    my ($vol,$path) = File::Spec->splitpath(
+                   File::Spec->rel2abs($0)
+            );
+    $path = File::Spec->catdir(
+        File::Spec->splitdir($path),
+        ,@_
+    );
+    return File::Spec->catpath($vol,$path,'');
 }
-
