@@ -7,8 +7,11 @@ use File::Spec();
 
 init();
 
-my $prod = Config::Loader->new( get_path('config_prod') );
-my $dev  = Config::Loader->new( get_path('config_dev') );
+my $debug = shift @ARGV;
+
+my $prod = Config::Loader->new( path => get_path('config_prod') , debug => $debug);
+my $dev  = Config::Loader->new( path => get_path('config_dev')  , debug => $debug);
+
 my $term = Term::ReadLine->new('Browser');
 
 while ( defined( my $path = $term->readline("Enter path:") ) ) {
@@ -50,12 +53,14 @@ sub dump_vals {
 #===================================
 sub get_path {
 #===================================
-    return File::Spec->catdir(
-            (  File::Spec->splitpath(
+    my ($vol,$path) = File::Spec->splitpath(
                    File::Spec->rel2abs($0)
-            ))[ 0, 1 ]
-            ,@_
-        );
+            );
+    $path = File::Spec->catdir(
+        File::Spec->splitdir($path),
+        ,@_
+    );
+    return File::Spec->catpath($vol,$path,'');
 }
 
 #===================================
